@@ -10,7 +10,10 @@ def koModel(model, field_names=None, data=None):
     if field_names:
         fields = field_names
     else:
-        fields = model._meta.get_all_field_names()
+        if hasattr(model, "knockout_fields"):
+            fields = model.knockout_fields()
+        else:
+            fields = model.to_dict().keys()
 
     modelViewString = render_to_string("knockout_modeler/model.html", {'modelName': modelName, 'fields': fields, 'data': data} )
 
@@ -18,10 +21,25 @@ def koModel(model, field_names=None, data=None):
 
 def koData(queryset, field_names):
 
-    modelName = queryset[0].__class__.__name__
-    modelDataString = render_to_string("knockout_modeler/data.html", {'modelName': modelName, 'queryset': queryset, 'field_names': field_names} )
+    modelName = queryset[0].__class__.__name__    
+    modelNameData = []
 
-    return modelDataString
+    if field_names:
+        fields = field_names
+    else:
+        if hasattr(model, "knockout_fields"):
+            fields = model.knockout_fields()
+        else:
+            fields = model.to_dict().keys()
+
+    for obj in queryset:
+        temp_dict = dict()
+        for field in fields:
+            temp_dict[field] = getattr(obj, field)
+        modelNameData.append(temp_dict)
+
+    dthandler = lambda obj: obj.isoformat() if isinstance(obj, datetime.datetime)  or isinstance(obj, datetime.date) else None
+    return "var " + modelName + "Data = " + json.dumps(modelNameData, default=dthandler) + ';'
 
 def ko(queryset, field_names):
 
